@@ -6,8 +6,8 @@
 ;; Author: Campbell Barton <ideasman42@gmail.com>
 
 ;; URL: https://codeberg.org/ideasman42/emacs-diff-ansi
-;; Package-Version: 20250913.2251
-;; Package-Revision: 1ae63be2381d
+;; Package-Version: 20251030.2352
+;; Package-Revision: 2d6acff42754
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
@@ -63,7 +63,8 @@
 
 ;; Note that this has it's values extracted and isn't used directly.
 (defface diff-ansi-default-face (list (list t :foreground "black" :background "black"))
-  "Face used to render black color.")
+  "Face used to render black color."
+  :group 'diff-ansi)
 
 (defcustom diff-ansi-tool-custom nil
   "Command to use when `diff-ansi-tool' is set to `custom'.
